@@ -124,6 +124,12 @@ Base.ones(A::ArrayPartition, dims::NTuple{N, Int}) where {N} = ones(A)
     return :($res)
 end
 
+## resize!
+function Base.resize!(A::ArrayPartition, sizes::Tuple)
+    resize!.(A.x, sizes)
+    A
+end
+
 ## vector space operations
 
 for op in (:+, :-)
@@ -579,3 +585,7 @@ end
     end
     return sum_expr
 end
+
+function Adapt.adapt_structure(to, ap::ArrayPartition)
+    ArrayPartition(map(x -> Adapt.adapt(to, x), ap.x)...)
+end
\ No newline at end of file
